@@ -2,6 +2,7 @@
 
 def modify(settings):
     
+    settings['INSTALLED_APPS'] += ('oppia.quiz', 'oppia.viz','crispy_forms','south','tastypie',)
     settings['MIDDLEWARE_CLASSES'] += ('oppia.middleware.LoginRequiredMiddleware',)
     settings['TEMPLATE_CONTEXT_PROCESSORS'] += ('oppia.context_processors.get_points',)
     settings['TEMPLATE_CONTEXT_PROCESSORS'] += ('oppia.context_processors.get_version',)
@@ -22,6 +23,8 @@ def modify(settings):
          r'^badges/api/',                # allow any URL under badges/api/* - auth handled by api_key
     ) 
     
+    settings['CRISPY_TEMPLATE_PACK'] = 'bootstrap3'
+    
     settings['OPPIA_POINTS'] = {
         'REGISTER':100,                             # given when user first registers
         'QUIZ_ATTEMPT_OWNER':5,                     # given to the quiz owner when another user attempts their quiz 
@@ -50,6 +53,8 @@ def modify(settings):
                                           
     settings['OPPIA_ALLOW_SELF_REGISTRATION'] = True    # turns on/off ability for users to self register
     
+    settings['OPPIA_SHOW_GRAVATARS'] = True
+    
     settings['OPPIA_STAFF_ONLY_UPLOAD'] = True          # prevents anyone without is_staff status being able to upload courses,
                                                         # setting to False allows any registered user to upload a course
     
